diff --git a/doc/release-notes/release-notes-25.0.md b/doc/release-notes/release-notes-25.0.md
deleted file mode 100644
index 919cb3b2f3..0000000000
--- a/doc/release-notes/release-notes-25.0.md
+++ /dev/null
@@ -1,340 +0,0 @@
-25.0 Release Notes
-==================
-
-Bitcoin Core version 25.0 is now available from:
-
-
-
-This release includes new features, various bug fixes and performance
-improvements, as well as updated translations.
-
-Please report bugs using the issue tracker at GitHub:
-
-
-
-To receive security and update notifications, please subscribe to:
-
-
-
-How to Upgrade
-==============
-
-If you are running an older version, shut it down. Wait until it has completely
-shut down (which might take a few minutes in some cases), then run the
-installer (on Windows) or just copy over `/Applications/Bitcoin-Qt` (on macOS)
-or `bitcoind`/`bitcoin-qt` (on Linux).
-
-Upgrading directly from a version of Bitcoin Core that has reached its EOL is
-possible, but it might take some time if the data directory needs to be migrated. Old
-wallet versions of Bitcoin Core are generally supported.
-
-Compatibility
-==============
-
-Bitcoin Core is supported and extensively tested on operating systems
-using the Linux kernel, macOS 10.15+, and Windows 7 and newer. Bitcoin
-Core should also work on most other Unix-like systems but is not as
-frequently tested on them. It is not recommended to use Bitcoin Core on
-unsupported systems.
-
-Notable changes
-===============
-
-P2P and network changes
------------------------
-
-- Transactions of non-witness size 65 bytes and above are now allowed by mempool
- and relay policy. This is to better reflect the actual afforded protections
- against CVE-2017-12842 and open up additional use-cases of smaller transaction sizes. (#26265)
-
-New RPCs
---------
-
-- The scanblocks RPC returns the relevant blockhashes from a set of descriptors by
- scanning all blockfilters in the given range. It can be used in combination with
- the getblockheader and rescanblockchain RPCs to achieve fast wallet rescans. Note
- that this functionality can only be used if a compact block filter index
- (-blockfilterindex=1) has been constructed by the node. (#23549)
-
-Updated RPCs
-------------
-
-- All JSON-RPC methods accept a new [named
- parameter](https://github.com/bitcoin/bitcoin/blob/master/doc/JSON-RPC-interface.md#parameter-passing) called `args` that can
- contain positional parameter values. This is a convenience to allow some
- parameter values to be passed by name without having to name every value. The
- python test framework and `bitcoin-cli` tool both take advantage of this, so
- for example:
-
-```sh
-bitcoin-cli -named createwallet wallet_name=mywallet load_on_startup=1
-```
-
-Can now be shortened to:
-
-```sh
-bitcoin-cli -named createwallet mywallet load_on_startup=1
-```
-
-- The `verifychain` RPC will now return `false` if the checks didn't fail,
- but couldn't be completed at the desired depth and level. This could be due
- to missing data while pruning, due to an insufficient dbcache or due to
- the node being shutdown before the call could finish. (#25574)
-
-- `sendrawtransaction` has a new, optional argument, `maxburnamount` with a default value of `0`.
- Any transaction containing an unspendable output with a value greater than `maxburnamount` will
- not be submitted. At present, the outputs deemed unspendable are those with scripts that begin
- with an `OP_RETURN` code (known as 'datacarriers'), scripts that exceed the maximum script size,
- and scripts that contain invalid opcodes.
-
-- The `testmempoolaccept` RPC now returns 2 additional results within the "fees" result:
- "effective-feerate" is the feerate including fees and sizes of transactions validated together if
- package validation was used, and also includes any modified fees from prioritisetransaction. The
- "effective-includes" result lists the wtxids of transactions whose modified fees and sizes were used
- in the effective-feerate (#26646).
-
-- `decodescript` may now infer a Miniscript descriptor under P2WSH context if it is not lacking
- information. (#27037)
-
-- `finalizepsbt` is now able to finalize a transaction with inputs spending Miniscript-compatible
- P2WSH scripts. (#24149)
-
-Changes to wallet related RPCs can be found in the Wallet section below.
-
-Build System
-------------
-
-- The `--enable-upnp-default` and `--enable-natpmp-default` options
- have been removed. If you want to use port mapping, you can
- configure it using a .conf file, or by passing the relevant
- options at runtime. (#26896)
-
-Updated settings
-----------------
-
-- If the `-checkblocks` or `-checklevel` options are explicitly provided by the
-user, but the verification checks cannot be completed due to an insufficient
-dbcache, Bitcoin Core will now return an error at startup. (#25574)
-
-- Ports specified in `-port` and `-rpcport` options are now validated at startup.
- Values that previously worked and were considered valid can now result in errors. (#22087)
-
-- Setting `-blocksonly` will now reduce the maximum mempool memory
- to 5MB (users may still use `-maxmempool` to override). Previously,
- the default 300MB would be used, leading to unexpected memory usage
- for users running with `-blocksonly` expecting it to eliminate
- mempool memory usage.
-
- As unused mempool memory is shared with dbcache, this also reduces
- the dbcache size for users running with `-blocksonly`, potentially
- impacting performance.
-- Setting `-maxconnections=0` will now disable `-dnsseed`
- and `-listen` (users may still set them to override).
-
-Changes to GUI or wallet related settings can be found in the GUI or Wallet section below.
-
-New settings
-------------
-
-- The `shutdownnotify` option is used to specify a command to execute synchronously
-before Bitcoin Core has begun its shutdown sequence. (#23395)
-
-
-Wallet
-------
-
-- The `minconf` option, which allows a user to specify the minimum number
-of confirmations a UTXO being spent has, and the `maxconf` option,
-which allows specifying the maximum number of confirmations, have been
-added to the following RPCs in #25375:
- - `fundrawtransaction`
- - `send`
- - `walletcreatefundedpsbt`
- - `sendall`
-
-- Added a new `next_index` field in the response in `listdescriptors` to
- have the same format as `importdescriptors` (#26194)
-
-- RPC `listunspent` now has a new argument `include_immature_coinbase`
- to include coinbase UTXOs that don't meet the minimum spendability
- depth requirement (which before were silently skipped). (#25730)
-
-- Rescans for descriptor wallets are now significantly faster if compact
- block filters (BIP158) are available. Since those are not constructed
- by default, the configuration option "-blockfilterindex=1" has to be
- provided to take advantage of the optimization. This improves the
- performance of the RPC calls `rescanblockchain`, `importdescriptors`
- and `restorewallet`. (#25957)
-
-- RPC `unloadwallet` now fails if a rescan is in progress. (#26618)
-
-- Wallet passphrases may now contain null characters.
- Prior to this change, only characters up to the first
- null character were recognized and accepted. (#27068)
-
-- Address Purposes strings are now restricted to the currently known values of "send",
- "receive", and "refund". Wallets that have unrecognized purpose strings will have
- loading warnings, and the `listlabels` RPC will raise an error if an unrecognized purpose
- is requested. (#27217)
-
-- In the `createwallet`, `loadwallet`, `unloadwallet`, and `restorewallet` RPCs, the
- "warning" string field is deprecated in favor of a "warnings" field that
- returns a JSON array of strings to better handle multiple warning messages and
- for consistency with other wallet RPCs. The "warning" field will be fully
- removed from these RPCs in v26. It can be temporarily re-enabled during the
- deprecation period by launching bitcoind with the configuration option
- `-deprecatedrpc=walletwarningfield`. (#27279)
-
-- Descriptor wallets can now spend coins sent to P2WSH Miniscript descriptors. (#24149)
-
-GUI changes
------------
-
-- The "Mask values" is a persistent option now. (gui#701)
-- The "Mask values" option affects the "Transaction" view now, in addition to the
- "Overview" one. (gui#708)
-
-REST
-----
-
-- A new `/rest/deploymentinfo` endpoint has been added for fetching various
- state info regarding deployments of consensus changes. (#25412)
-
-Binary verification
-----
-
-- The binary verification script has been updated. In previous releases it
- would verify that the binaries had been signed with a single "release key".
- In this release and moving forward it will verify that the binaries are
- signed by a _threshold of trusted keys_. For more details and
- examples, see:
- https://github.com/bitcoin/bitcoin/blob/master/contrib/verify-binaries/README.md
- (#27358)
-
-Low-level changes
-=================
-
-RPC
----
-
-- The JSON-RPC server now rejects requests where a parameter is specified multiple
- times with the same name, instead of silently overwriting earlier parameter values
- with later ones. (#26628)
-- RPC `listsinceblock` now accepts an optional `label` argument
- to fetch incoming transactions having the specified label. (#25934)
-- Previously `setban`, `addpeeraddress`, `walletcreatefundedpsbt`, methods
- allowed non-boolean and non-null values to be passed as boolean parameters.
- Any string, number, array, or object value that was passed would be treated
- as false. After this change, passing any value except `true`, `false`, or
- `null` now triggers a JSON value is not of expected type error. (#26213)
-
-Credits
-=======
-
-Thanks to everyone who directly contributed to this release:
-
-- 0xb10c
-- 721217.xyz
-- @RandyMcMillan
-- amadeuszpawlik
-- Amiti Uttarwar
-- Andrew Chow
-- Andrew Toth
-- Anthony Towns
-- Antoine Poinsot
-- Aurèle Oulès
-- Ben Woosley
-- Bitcoin Hodler
-- brunoerg
-- Bushstar
-- Carl Dong
-- Chris Geihsler
-- Cory Fields
-- David Gumberg
-- dergoegge
-- Dhruv Mehta
-- Dimitris Tsapakidis
-- dougEfish
-- Douglas Chimento
-- ekzyis
-- Elichai Turkel
-- Ethan Heilman
-- Fabian Jahr
-- FractalEncrypt
-- furszy
-- Gleb Naumenko
-- glozow
-- Greg Sanders
-- Hennadii Stepanov
-- hernanmarino
-- ishaanam
-- ismaelsadeeq
-- James O'Beirne
-- jdjkelly@gmail.com
-- Jeff Ruane
-- Jeffrey Czyz
-- Jeremy Rubin
-- Jesse Barton
-- João Barbosa
-- JoaoAJMatos
-- John Moffett
-- Jon Atack
-- Jonas Schnelli
-- jonatack
-- Joshua Kelly
-- josibake
-- Juan Pablo Civile
-- kdmukai
-- klementtan
-- Kolby ML
-- kouloumos
-- Kristaps Kaupe
-- laanwj
-- Larry Ruane
-- Leonardo Araujo
-- Leonardo Lazzaro
-- Luke Dashjr
-- MacroFake
-- MarcoFalke
-- Martin Leitner-Ankerl
-- Martin Zumsande
-- Matt Whitlock
-- Matthew Zipkin
-- Michael Ford
-- Miles Liu
-- mruddy
-- Murray Nesbitt
-- muxator
-- omahs
-- pablomartin4btc
-- Pasta
-- Pieter Wuille
-- Pttn
-- Randall Naar
-- Riahiamirreza
-- roconnor-blockstream
-- Russell O'Connor
-- Ryan Ofsky
-- S3RK
-- Sebastian Falbesoner
-- Seibart Nedor
-- sinetek
-- Sjors Provoost
-- Skuli Dulfari
-- SomberNight
-- Stacie Waleyko
-- stickies-v
-- stratospher
-- Suhas Daftuar
-- Suriyaa Sundararuban
-- TheCharlatan
-- Vasil Dimov
-- Vasil Stoyanov
-- virtu
-- w0xlt
-- willcl-ark
-- yancy
-- Yusuf Sahin HAMZA
-
-As well as to everyone that helped with translations on
-[Transifex](https://www.transifex.com/bitcoin/bitcoin/).
\ No newline at end of file
diff --git a/src/qt/locale/bitcoin_cmn.ts b/src/qt/locale/bitcoin_cmn.ts
index d49d28d2e9..1dd97ee008 100644
--- a/src/qt/locale/bitcoin_cmn.ts
+++ b/src/qt/locale/bitcoin_cmn.ts
@@ -1359,12 +1359,12 @@ The migration process will create a backup of the wallet before migrating. This
窗体
-
- 最近的交易可能還看不到,因此錢包餘額可能不正確。在錢包軟體完成跟 bitcoin 網路的同步後,這裡的資訊就會正確。詳情請見下面。
+
+ 最近的交易可能還看不到,因此錢包餘額可能不正確。在錢包軟體完成跟 qtum 網路的同步後,這裡的資訊就會正確。詳情請見下面。
-
- 嘗試花費受尚未顯示的交易影響的比特幣將不會被網路接受。
+
+ 嘗試花費受尚未顯示的交易影響的QTUM將不會被網路接受。
diff --git a/src/qt/locale/bitcoin_es.ts b/src/qt/locale/bitcoin_es.ts
index 74e18f30ff..2e647aa8cf 100644
--- a/src/qt/locale/bitcoin_es.ts
+++ b/src/qt/locale/bitcoin_es.ts
@@ -58,13 +58,13 @@
&Elegir
-
- Estas son tus direcciones de Bitcoin para enviar pagos. Revisa siempre el importe y la dirección de recepción antes de enviar monedas.
+
+ Estas son tus direcciones de Qtum para enviar pagos. Revisa siempre el importe y la dirección de recepción antes de enviar monedas.
- Estas son tus direcciones de Bitcoin para recibir pagos. Usa el botón "Crear nueva dirección de recepción" en la pestaña "Recibir" para crear nuevas direcciones.
+ Estas son tus direcciones de Qtum para recibir pagos. Usa el botón "Crear nueva dirección de recepción" en la pestaña "Recibir" para crear nuevas direcciones.
Solo es posible firmar con direcciones de tipo "legacy".
@@ -164,8 +164,8 @@ Solo es posible firmar con direcciones de tipo "legacy".
Confirmar cifrado del monedero
-
- Atención: Si cifras el monedero y pierdes la frase de contraseña, <b>¡PERDERÁS TODOS TUS BITCOINS</b>!
+
+ Atención: Si cifras el monedero y pierdes la frase de contraseña, <b>¡PERDERÁS TODOS TUS QTUMS</b>!
@@ -184,8 +184,8 @@ Solo es posible firmar con direcciones de tipo "legacy".
Introduce la frase de contraseña antigua y la nueva para el monedero.
-
- Recuerda que cifrar tu monedero no garantiza la protección total de tus bitcoins contra robos si el equipo está infectado con malware.
+
+ Recuerda que cifrar tu monedero no garantiza la protección total de tus qtums contra robos si el equipo está infectado con malware.
@@ -303,8 +303,8 @@ Solo es posible firmar con direcciones de tipo "legacy".
Importe
-
- Ingresa una dirección de Bitcoin (p. ej., %1)
+
+ Ingresa una dirección de Qtum (p. ej., %1)
@@ -507,16 +507,16 @@ Solo es posible firmar con direcciones de tipo "legacy".
Firmar &mensaje…
-
- Firmar mensajes con tus direcciones Bitcoin para probar la propiedad
+
+ Firmar mensajes con tus direcciones Qtum para probar la propiedad&Verificar mensaje…
-
- Verificar mensajes para comprobar que fueron firmados con la dirección Bitcoin indicada
+
+ Verificar mensajes para comprobar que fueron firmados con la dirección Qtum indicada
@@ -575,8 +575,8 @@ Solo es posible firmar con direcciones de tipo "legacy".
Conectando con pares…
-
- Solicitar pagos (genera códigos QR y URI de tipo "bitcoin:")
+
+ Solicitar pagos (genera códigos QR y URI de tipo "qtum:")
@@ -654,8 +654,8 @@ Solo es posible firmar con direcciones de tipo "legacy".
&Direcciones de recepción
-
- Abrir un URI de tipo "bitcoin:"
+
+ Abrir un URI de tipo "qtum:"
@@ -759,8 +759,8 @@ Solo es posible firmar con direcciones de tipo "legacy".
A substring of the tooltip.
- %n conexión activa con la red Bitcoin.
- %n conexiones activas con la red Bitcoin.
+ %n conexión activa con la red Qtum.
+ %n conexiones activas con la red Qtum.
@@ -1278,8 +1278,8 @@ El proceso de migración creará una copia de seguridad del monedero antes de mi
Editar dirección de envío
-
- La dirección introducida "%1" no es una dirección Bitcoin válida.
+
+ La dirección introducida "%1" no es una dirección Qtum válida.
@@ -1450,8 +1450,8 @@ El proceso de migración creará una copia de seguridad del monedero antes de mi
Formulario
-
- Es posible que las transacciones recientes aún no estén visibles y, por lo tanto, el saldo del monedero podría ser incorrecto. Esta información será correcta una vez que el monedero haya terminado de sincronizarse con la red Bitcoin, como se detalla a continuación.
+
+ Es posible que las transacciones recientes aún no estén visibles y, por lo tanto, el saldo del monedero podría ser incorrecto. Esta información será correcta una vez que el monedero haya terminado de sincronizarse con la red Qtum, como se detalla a continuación.
@@ -1505,8 +1505,8 @@ El proceso de migración creará una copia de seguridad del monedero antes de mi
OpenURIDialog
-
- Abrir URI de tipo "bitcoin:"
+
+ Abrir URI de tipo "qtum:"
@@ -1665,16 +1665,16 @@ El proceso de migración creará una copia de seguridad del monedero antes de mi
&Ruta al script del firmante externo
-
- Abrir automáticamente el puerto del cliente Bitcoin en el enrutador. Esta opción solo funciona cuando el enrutador admite UPnP y está activado.
+
+ Abrir automáticamente el puerto del cliente Qtum en el enrutador. Esta opción solo funciona cuando el enrutador admite UPnP y está activado.Asignar puerto mediante &UPnP
-
- Abre el puerto del cliente de Bitcoin en el enrutador automáticamente. Esto solo funciona cuando el enrutador soporta NAT-PMP y está activo. El puerto externo podría ser elegido al azar.
+
+ Abre el puerto del cliente de Qtum en el enrutador automáticamente. Esto solo funciona cuando el enrutador soporta NAT-PMP y está activo. El puerto externo podría ser elegido al azar.
@@ -1874,8 +1874,8 @@ El proceso de migración creará una copia de seguridad del monedero antes de mi
Formulario
-
- La información mostrada puede estar desactualizada. El monedero se sincroniza automáticamente con la red de Bitcoin después de establecer una conexión, pero este proceso aún no se ha completado.
+
+ La información mostrada puede estar desactualizada. El monedero se sincroniza automáticamente con la red de Qtum después de establecer una conexión, pero este proceso aún no se ha completado.
@@ -2085,16 +2085,16 @@ El proceso de migración creará una copia de seguridad del monedero antes de mi
Error en la solicitud de pago
-
- No se puede iniciar el controlador "bitcoin: click-to-pay"
+
+ No se puede iniciar el controlador "qtum: click-to-pay"Gestión de URI
-
- "bitcoin://" no es un URI válido. Usa "bitcoin:" en su lugar.
+
+ "qtum://" no es un URI válido. Usa "qtum:" en su lugar.
-
- No se puede analizar el URI. Esto se puede deber a una dirección de Bitcoin inválida o a parámetros de URI con formato incorrecto.
+
+ No se puede analizar el URI. Esto se puede deber a una dirección de Qtum inválida o a parámetros de URI con formato incorrecto.
@@ -2685,8 +2685,8 @@ Para obtener más información sobre cómo usar esta consola, escribe %6.
&Mensaje:
-
- Mensaje opcional para adjuntar a la solicitud de pago, que se mostrará cuando se abra la solicitud. Nota: Este mensaje no se enviará con el pago a través de la red de Bitcoin.
+
+ Mensaje opcional para adjuntar a la solicitud de pago, que se mostrará cuando se abra la solicitud. Nota: Este mensaje no se enviará con el pago a través de la red de Qtum.
@@ -2978,8 +2978,8 @@ Note: Since the fee is calculated on a per-byte basis, a fee rate of "100 satos
Nota: Dado que la comisión se calcula por byte, una tasa de "100 satoshis por kvB" para una transacción de 500 bytes virtuales (la mitad de 1 kvB) supondría finalmente una comisión de solo 50 satoshis.
-
- Cuando hay menos volumen de transacciones que espacio en los bloques, los mineros y los nodos de retransmisión pueden aplicar una comisión mínima. Está bien pagar solo esta comisión mínima, pero ten en cuenta que esto puede ocasionar que una transacción nunca se confirme una vez que haya más demanda de transacciones de Bitcoin de la que puede procesar la red.
+
+ Cuando hay menos volumen de transacciones que espacio en los bloques, los mineros y los nodos de retransmisión pueden aplicar una comisión mínima. Está bien pagar solo esta comisión mínima, pero ten en cuenta que esto puede ocasionar que una transacción nunca se confirme una vez que haya más demanda de transacciones de Qtum de la que puede procesar la red.
@@ -3064,8 +3064,8 @@ Nota: Dado que la comisión se calcula por byte, una tasa de "100 satoshis por k
&Crear sin firmar
-
- Crea una transacción de Bitcoin parcialmente firmada (TBPF) para usarla, por ejemplo, con un monedero %1 sin conexión o un monedero de hardware compatible con TBPF.
+
+ Crea una transacción de Qtum parcialmente firmada (TBPF) para usarla, por ejemplo, con un monedero %1 sin conexión o un monedero de hardware compatible con TBPF.
@@ -3126,7 +3126,7 @@ Nota: Dado que la comisión se calcula por byte, una tasa de "100 satoshis por k
Text to inform a user attempting to create a transaction of their current options. At this stage, a user can only create a PSBT. This string is displayed when private keys are disabled and an external signer is not available.
- Revisa por favor la propuesta de transacción. Esto producirá una transacción de Bitcoin parcialmente firmada (TBPF) que puedes guardar o copiar y, luego, firmar; por ejemplo, con un monedero %1 fuera de línea o un monedero de hardware compatible con TBPF.
+ Revisa por favor la propuesta de transacción. Esto producirá una transacción de Qtum parcialmente firmada (TBPF) que puedes guardar o copiar y, luego, firmar; por ejemplo, con un monedero %1 fuera de línea o un monedero de hardware compatible con TBPF.
@@ -3136,7 +3136,7 @@ Nota: Dado que la comisión se calcula por byte, una tasa de "100 satoshis por k
Text to inform a user attempting to create a transaction of their current options. At this stage, a user can send their transaction or create a PSBT. This string is displayed when both private keys and PSBT controls are enabled.
- Revisa por favor la transacción. Puedes crear y enviar esta transacción de Bitcoin parcialmente firmada (TBPF), que además puedes guardar o copiar y, luego, firmar; por ejemplo, con un monedero %1 sin conexión o un monedero de hardware compatible con TBPF.
+ Revisa por favor la transacción. Puedes crear y enviar esta transacción de Qtum parcialmente firmada (TBPF), que además puedes guardar o copiar y, luego, firmar; por ejemplo, con un monedero %1 sin conexión o un monedero de hardware compatible con TBPF.
@@ -3213,8 +3213,8 @@ Nota: Dado que la comisión se calcula por byte, una tasa de "100 satoshis por k
-
- Advertencia: Dirección de Bitcoin no válida
+
+ Advertencia: Dirección de Qtum no válida
@@ -3252,8 +3252,8 @@ Nota: Dado que la comisión se calcula por byte, una tasa de "100 satoshis por k
Escoger una dirección usada anteriormente
-
- La dirección de Bitcoin a la que se enviará el pago
+
+ La dirección de Qtum a la que se enviará el pago
@@ -3268,8 +3268,8 @@ Nota: Dado que la comisión se calcula por byte, una tasa de "100 satoshis por k
El importe que se enviará en la unidad seleccionada
-
- La comisión se deducirá del importe que se envía. El destinatario recibirá menos bitcoins que los que ingreses en el campo del importe. Si se seleccionan varios destinatarios, la comisión se dividirá por igual.
+
+ La comisión se deducirá del importe que se envía. El destinatario recibirá menos qtums que los que ingreses en el campo del importe. Si se seleccionan varios destinatarios, la comisión se dividirá por igual.
@@ -3288,8 +3288,8 @@ Nota: Dado que la comisión se calcula por byte, una tasa de "100 satoshis por k
Introduce una etiqueta para esta dirección a fin de añadirla al listado de direcciones utilizadas
-
- Un mensaje adjunto al URI de tipo "bitcoin:" que se almacenará con la transacción a modo de referencia. Nota: Este mensaje no se enviará por la red de Bitcoin.
+
+ Un mensaje adjunto al URI de tipo "qtum:" que se almacenará con la transacción a modo de referencia. Nota: Este mensaje no se enviará por la red de Qtum.
@@ -3315,11 +3315,11 @@ Nota: Dado que la comisión se calcula por byte, una tasa de "100 satoshis por k
- Puedes firmar mensajes o acuerdos con tus direcciones para demostrar que puedes recibir los bitcoins que se envíen a ellas. Ten cuidado de no firmar cosas confusas o al azar, ya que los ataques de phishing pueden tratar de engañarte para que les envíes la firma con tu identidad. Firma solo declaraciones totalmente detalladas con las que estés de acuerdo.
+ Puedes firmar mensajes o acuerdos con tus direcciones para demostrar que puedes recibir los qtums que se envíen a ellas. Ten cuidado de no firmar cosas confusas o al azar, ya que los ataques de phishing pueden tratar de engañarte para que les envíes la firma con tu identidad. Firma solo declaraciones totalmente detalladas con las que estés de acuerdo.
-
- La dirección de Bitcoin con la que se firmará el mensaje
+
+ La dirección de Qtum con la que se firmará el mensaje
@@ -3342,8 +3342,8 @@ Nota: Dado que la comisión se calcula por byte, una tasa de "100 satoshis por k
Copiar la firma actual al portapapeles del sistema
-
- Firma el mensaje para demostrar que esta dirección de Bitcoin te pertenece
+
+ Firma el mensaje para demostrar que esta dirección de Qtum te pertenece
@@ -3366,8 +3366,8 @@ Nota: Dado que la comisión se calcula por byte, una tasa de "100 satoshis por k
Ingresa la dirección del destinatario, el mensaje (recuerda copiar los saltos de línea, espacios, tabulaciones, etc. con exactitud) y la firma a continuación para verificar el mensaje. Ten cuidado de no leer en la firma más de lo que contiene el propio mensaje firmado, para evitar ser víctima de un engaño por ataque de intermediario. Ten en cuenta que esto solo prueba que la parte firmante recibe con esta dirección; no puede demostrar la condición de remitente de ninguna transacción.
-
- La dirección de Bitcoin con la que se firmó el mensaje
+
+ La dirección de Qtum con la que se firmó el mensaje
@@ -3378,8 +3378,8 @@ Nota: Dado que la comisión se calcula por byte, una tasa de "100 satoshis por k
La firma proporcionada cuando el mensaje fue firmado
-
- Verifica el mensaje para asegurarte de que se firmó con la dirección de Bitcoin especificada.
+
+ Verifica el mensaje para asegurarte de que se firmó con la dirección de Qtum especificada.
@@ -4939,4 +4939,4 @@ No es posible restaurar el respaldo del monedero.
El archivo de configuración no puede escribirse
-
\ No newline at end of file
+
diff --git a/src/qt/locale/bitcoin_hak.ts b/src/qt/locale/bitcoin_hak.ts
index 5eb5e0dfc4..ab817ef214 100644
--- a/src/qt/locale/bitcoin_hak.ts
+++ b/src/qt/locale/bitcoin_hak.ts
@@ -1371,12 +1371,12 @@ The migration process will create a backup of the wallet before migrating. This
窗体
-
- 最近的交易可能還看不到,因此錢包餘額可能不正確。在錢包軟體完成跟 bitcoin 網路的同步後,這裡的資訊就會正確。詳情請見下面。
+
+ 最近的交易可能還看不到,因此錢包餘額可能不正確。在錢包軟體完成跟 qtum 網路的同步後,這裡的資訊就會正確。詳情請見下面。
-
- 嘗試花費受尚未顯示的交易影響的比特幣將不會被網路接受。
+
+ 嘗試花費受尚未顯示的交易影響的QTUM將不會被網路接受。
diff --git a/src/qt/locale/bitcoin_ko.ts b/src/qt/locale/bitcoin_ko.ts
index 511ac96a1f..2e8a3ddcd2 100755
--- a/src/qt/locale/bitcoin_ko.ts
+++ b/src/qt/locale/bitcoin_ko.ts
@@ -169,6 +169,14 @@ Signing is only possible with addresses of the type 'legacy'.
Expanded name of the CSV file format. See: https://en.wikipedia.org/wiki/Comma-separated_values.콤마로 분리된 파일
+
+
+ 보내는 주소들 - %1
+
+
+
+ 받는 주소들 - %1
+ 내보내기 실패
@@ -300,6 +308,10 @@ Signing is only possible with addresses of the type 'legacy'.
암호 해제를 위한 비밀번호가 정확하지 않습니다.
+
+
+ 지갑 암호화 해제를 위해 입력된 비밀문구가 정확하지 않습니다. 비밀문구가 공백 문자 (0 바이트)를 포함하고 있습니다. 만약 비밀문구가 25.0 버전 이전의 QTUM 코어 소프트웨어에 의해 설정되었다면, 비밀문구를 첫 공백 문자 이전까지 입력해보세요. 이렇게 해서 성공적으로 입력되었다면, 차후 이런 문제가 발생하지 않도록 비밀문구를 새로이 설정해 주세요.
+ 지갑의 비밀번호가 성공적으로 수정되었습니다.
@@ -307,6 +319,12 @@ Signing is only possible with addresses of the type 'legacy'.
암호 변경에 실패하였습니다.
+
+
+
+ 지갑 암호화 해제를 위해 입력된 예전 비밀문구가 정확하지 않습니다. 비밀문구가 공백 문자 (0 바이트)를 포함하고 있습니다. 만약 비밀문구가 25.0 버전 이전의 QTUM 코어 소프트웨어에 의해 설정되었다면, 비밀문구를 첫 공백 문자 이전까지 입력해보세요.
+
+ 경고: Cap Lock 키가 활성화되어 있습니다
@@ -733,6 +751,14 @@ Signing is only possible with addresses of the type 'legacy'.
A context menu item. The network activity was disabled previously.네트워크 활성화 하기
+
+
+ 블록 헤더들을 사전 동기화 중 (%1%)...
+
+
+
+ 지갑 생성 오류
+ 헤더 동기화 중 (%1%)...
@@ -1170,6 +1196,10 @@ Signing is only possible with addresses of the type 'legacy'.
서명자를 나열할 수 없습니다.
+
+
+ 너무 많은 외부 서명자들이 발견됨
+ LoadWalletsActivity
@@ -1694,6 +1724,10 @@ Signing is only possible with addresses of the type 'legacy'.
(Full 체인이 되려면 %n GB 가 필요합니다.)
+
+
+ 데이터 디렉토리를 선택하세요
+ 해당 디렉토리에 최소 %1 GB의 데이터가 저장될 예정이고 시간이 흐를수록 데이터는 늘어날 예정입니다.
@@ -1729,6 +1763,10 @@ Signing is only possible with addresses of the type 'legacy'.
초기 동기화는 매우 중요하고 이 과정에서 발견하지 못했던 컴퓨터 하드웨어 이슈가 드러날 수 있습니다. %1에 대한 동기화는 지난 종료 직전 상태부터 실행될 예정입니다.
+
+
+ OK를 클릭하면, %1는 %4가 최초 출시된 %3에 있는 가장 오래된 트랜잭션들부터 시작하여 전체 %4 블록체인 (%2GB)을 내려 받고 처리하기 시작합니다.
+ ModalOverlay
@@ -1784,6 +1822,10 @@ Signing is only possible with addresses of the type 'legacy'.
알 수 없음. 헤더 동기화 중(%1, %2)...
+
+
+ 알려지지 않음. 블록 헤더들을 사전 동기화 중 (%1, %2%)...
+ 지갑 백업 안내
@@ -1869,6 +1911,10 @@ Please make sure to keep an updated antivirus and operating system. We can not r
스크립트 검증 스레드 개수
+
+
+ %1가 호환되는 스크립트가 있는 전체 경로 (예시 - C:\Downloads\hwi.exe or /Users/you/Downloads/hwi.py). 주의: 멀웨어가 당신의 코인들을 훔쳐갈 수도 있습니다!
+ 프록시 IP 주소 (예, IPv4: 127.0.0.1 / IPv6: ::1)
@@ -5171,6 +5217,26 @@ Note: Since the fee is calculated on a per-byte basis, a fee rate of "100 satos
Title of progress window which is displayed when wallets are being restored.지갑 복원하기
+
+
+ Descriptive text of the restore wallets progress window which indicates to the user that wallets are currently being restored.
+ 지갑 복구 중 <b>%1</b>...
+
+
+
+ Title of message box which is displayed when the wallet could not be restored.
+ 지갑 복구 실패
+
+
+
+ Title of message box which is displayed when the wallet is restored with some warning.
+ 경고 (지갑 복구)
+
+
+
+ Title of message box which is displayed when the wallet is successfully restored.
+ 지갑 복구 관련 메세지
+ WalletController
@@ -5281,6 +5347,11 @@ Go to File > Open Wallet to load a wallet.
PSBT 복사됨
+
+
+ Fee-bump PSBT saved
+ 클립보드로 복사됨
+ 거래 서명 실패
@@ -5907,4 +5978,4 @@ Go to File > Open Wallet to load a wallet.
설정파일이 쓰여지지 않았습니다.
-
\ No newline at end of file
+
diff --git a/src/qt/locale/bitcoin_mk.ts b/src/qt/locale/bitcoin_mk.ts
index d9ab2b067a..feef93ed88 100644
--- a/src/qt/locale/bitcoin_mk.ts
+++ b/src/qt/locale/bitcoin_mk.ts
@@ -58,11 +58,11 @@
Избери
- These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.
- Ова се вашите Bitcoin-адреси за испраќање плаќања. Секогаш проверувајте ја количината и адресите за примање пред да испраќате монети.
+ These are your Qtum addresses for sending payments. Always check the amount and the receiving address before sending coins.
+ Ова се вашите Qtum-адреси за испраќање плаќања. Секогаш проверувајте ја количината и адресите за примање пред да испраќате монети.
- These are your Bitcoin addresses for receiving payments. Use the 'Create new receiving address' button in the receive tab to create new addresses.
+ These are your Qtum addresses for receiving payments. Use the 'Create new receiving address' button in the receive tab to create new addresses.
Signing is only possible with addresses of the type 'legacy'.Ова се вашите биткоин-адреси за примање плаќања. Користете го копчето „Создавање нови адреси“ во јазичето за примање за да создадете нови адреси. Потпишувањето е можно само со „наследни“ адреси.
@@ -155,7 +155,7 @@ Signing is only possible with addresses of the type 'legacy'.
Потврди шифрирање на паричникот
- Warning: If you encrypt your wallet and lose your passphrase, you will <b>LOSE ALL OF YOUR BITCOINS</b>!
+ Warning: If you encrypt your wallet and lose your passphrase, you will <b>LOSE ALL OF YOUR QTUMS</b>!ВНИМАНИЕ: Ако го шифрирате вашиот паричник и ја изгубите лозинката, <b>ЌЕ ГИ ИЗГУБИТЕ СИТЕ БИТКОИНИ</b>!
@@ -175,7 +175,7 @@ Signing is only possible with addresses of the type 'legacy'.
Внесете ја старата и новата лозинка за паричникот.
- Remember that encrypting your wallet cannot fully protect your bitcoins from being stolen by malware infecting your computer.
+ Remember that encrypting your wallet cannot fully protect your qtums from being stolen by malware infecting your computer.Запомнете дека шифрирањето на вашиот паричник не може целосно да ги заштити вашите биткоини од кражба од злонамерен софтвер, заразувајќи го вашиот сметач.
@@ -478,7 +478,7 @@ Signing is only possible with addresses of the type 'legacy'.
Потпиши &порака...
- Sign messages with your Bitcoin addresses to prove you own them
+ Sign messages with your Qtum addresses to prove you own themНапишете пораки со вашата биткоин-адреса за да докажете дека е ваша.
@@ -486,7 +486,7 @@ Signing is only possible with addresses of the type 'legacy'.
&Потврди порака...
- Verify messages to ensure they were signed with specified Bitcoin addresses
+ Verify messages to ensure they were signed with specified Qtum addressesПотврдување на пораките за да се знае дека се напишани со дадените биткоин-адреси.
@@ -546,7 +546,7 @@ Signing is only possible with addresses of the type 'legacy'.
Поврзување со врсници...
- Request payments (generates QR codes and bitcoin: URIs)
+ Request payments (generates QR codes and qtum: URIs)Барање за плаќања (создава QR-кодови и биткоин: URI)
@@ -602,7 +602,7 @@ Signing is only possible with addresses of the type 'legacy'.
Во тек
- Load Partially Signed Bitcoin Transaction
+ Load Partially Signed Qtum TransactionВчитајте делумно потпишана биткоин-трансакција
@@ -610,7 +610,7 @@ Signing is only possible with addresses of the type 'legacy'.
Вчитај PSBT од &клипбордот...
- Load Partially Signed Bitcoin Transaction from clipboard
+ Load Partially Signed Qtum Transaction from clipboardВчитајте делумно потпишана биткоин-трансакција од клипбордот
@@ -630,7 +630,7 @@ Signing is only possible with addresses of the type 'legacy'.
&Примање на адреси
- Open a bitcoin: URI
+ Open a qtum: URIОтвори биткоин: URI
@@ -660,7 +660,7 @@ Signing is only possible with addresses of the type 'legacy'.
Затвори ги сите паричници
- Show the %1 help message to get a list with possible Bitcoin command-line options
+ Show the %1 help message to get a list with possible Qtum command-line optionsПрикажи %1 помошна порака за да добиеш список на можни биткоин-команди.
@@ -1371,4 +1371,4 @@ Signing is only possible with addresses of the type 'legacy'.
Недоволно средства
-
\ No newline at end of file
+
diff --git a/src/qt/locale/bitcoin_ne.ts b/src/qt/locale/bitcoin_ne.ts
index c6cb8f6ce3..08dc5f2f30 100644
--- a/src/qt/locale/bitcoin_ne.ts
+++ b/src/qt/locale/bitcoin_ne.ts
@@ -174,7 +174,7 @@
वालेटको लागि पुरानो पासफ्रेज र नयाँ पासफ्रेज प्रविष्ट गर्नुहोस्।
- Remember that encrypting your wallet cannot fully protect your bitcoins from being stolen by malware infecting your computer.
+ Remember that encrypting your wallet cannot fully protect your qtums from being stolen by malware infecting your computer.याद गर्नुहोस् कि तपाईको वालेट इन्क्रिप्ट गर्नाले तपाईको बिटकोइनलाई तपाईको कम्प्युटरमा मालवेयरले चोरी हुनबाट पूर्णतया सुरक्षित गर्न सक्दैन।
diff --git a/src/qt/locale/bitcoin_ru.ts b/src/qt/locale/bitcoin_ru.ts
index 8c6496c7f6..2978f4078c 100644
--- a/src/qt/locale/bitcoin_ru.ts
+++ b/src/qt/locale/bitcoin_ru.ts
@@ -184,8 +184,8 @@ Signing is only possible with addresses of the type 'legacy'.
Введите старую и новую парольные фразы для кошелька.
- Remember that encrypting your wallet cannot fully protect your bitcoins from being stolen by malware infecting your computer.
- Помните, что шифрование кошелька не может полностью защитить ваши биткоины от кражи вредоносным ПО, заразившим ваш компьютер.
+ Remember that encrypting your wallet cannot fully protect your qtums from being stolen by malware infecting your computer.
+ Помните, что шифрование кошелька не может полностью защитить ваши qtumы от кражи вредоносным ПО, заразившим ваш компьютер.Wallet to be encrypted
@@ -711,7 +711,7 @@ Signing is only possible with addresses of the type 'legacy'.
Open a qtum: URI
- Открыть биткойн: URI
+ Открыть qtum: URIOpen Wallet
@@ -5030,4 +5030,4 @@ Unable to restore backup of wallet.
Файл настроек не может быть записан
-
\ No newline at end of file
+
diff --git a/src/qt/locale/bitcoin_sw.ts b/src/qt/locale/bitcoin_sw.ts
index 6e1f82de1d..8c0ff5e931 100644
--- a/src/qt/locale/bitcoin_sw.ts
+++ b/src/qt/locale/bitcoin_sw.ts
@@ -156,8 +156,8 @@ Kutia sahihi kunawezekana tu kwa anwani za aina ya 'urithi'.Thibitisha usimbaji fiche wa pochi
- Warning: If you encrypt your wallet and lose your passphrase, you will <b>LOSE ALL OF YOUR BITCOINS</b>!
- Ilani: Ikiwa utasimba pochi yako na ukapoteza nenosiri lako, <b> UTAPOTEZA BITCOIN ZAKO ZOTE </b>!
+ Warning: If you encrypt your wallet and lose your passphrase, you will <b>LOSE ALL OF YOUR QTUMS</b>!
+ Ilani: Ikiwa utasimba pochi yako na ukapoteza nenosiri lako, <b> UTAPOTEZA QTUM ZAKO ZOTE </b>!Are you sure you wish to encrypt your wallet?
@@ -176,8 +176,8 @@ Kutia sahihi kunawezekana tu kwa anwani za aina ya 'urithi'.
Ingiza nenosiri la zamani na nenosiri jipya la pochi yako.
- Remember that encrypting your wallet cannot fully protect your bitcoins from being stolen by malware infecting your computer.
- Kumbuka kwamba usimbaji fiche wa mkoba wako hauwezi kulinda bitcoins zako zisiibiwe na programu hasidi kuambukiza kompyuta yako.
+ Remember that encrypting your wallet cannot fully protect your qtums from being stolen by malware infecting your computer.
+ Kumbuka kwamba usimbaji fiche wa mkoba wako hauwezi kulinda qtums zako zisiibiwe na programu hasidi kuambukiza kompyuta yako.Wallet to be encrypted
@@ -382,8 +382,8 @@ Kutia sahihi kunawezekana tu kwa anwani za aina ya 'urithi'.
Proxy imeamilishwa: %1
- Send coins to a Bitcoin address
- Tuma sarafu kwa anwani ya Bitcoin
+ Send coins to a Qtum address
+ Tuma sarafu kwa anwani ya QtumBackup wallet to another location
@@ -414,12 +414,12 @@ Kutia sahihi kunawezekana tu kwa anwani za aina ya 'urithi'.
Saini &ujumbe...
- Sign messages with your Bitcoin addresses to prove you own them
- Saini ujumbe na anwani zako za Bitcoin ili kuthibitisha umiliki wao.
+ Sign messages with your Qtum addresses to prove you own them
+ Saini ujumbe na anwani zako za Qtum ili kuthibitisha umiliki wao.
- Verify messages to ensure they were signed with specified Bitcoin addresses
- Hakikisha ujumbe umethibitishwa kuwa ulisainiwa na anwani za Bitcoin zilizotajwa
+ Verify messages to ensure they were signed with specified Qtum addresses
+ Hakikisha ujumbe umethibitishwa kuwa ulisainiwa na anwani za Qtum zilizotajwaOpen &URI…
@@ -474,8 +474,8 @@ Kutia sahihi kunawezekana tu kwa anwani za aina ya 'urithi'.
Kuunganisha na wenzako wa kushirikiana...
- Request payments (generates QR codes and bitcoin: URIs)
- Omba malipo (huzalisha nambari za QR na bitcoin: URIs)
+ Request payments (generates QR codes and qtum: URIs)
+ Omba malipo (huzalisha nambari za QR na qtum: URIs)Show the list of used sending addresses and labels
@@ -889,4 +889,4 @@ Kutia sahihi kunawezekana tu kwa anwani za aina ya 'urithi'.
Kuthibitisha mkoba/mikoba
-
\ No newline at end of file
+
diff --git a/src/qt/locale/bitcoin_zh-Hans.ts b/src/qt/locale/bitcoin_zh-Hans.ts
index a5baba7607..427766f217 100644
--- a/src/qt/locale/bitcoin_zh-Hans.ts
+++ b/src/qt/locale/bitcoin_zh-Hans.ts
@@ -1361,7 +1361,7 @@ The migration process will create a backup of the wallet before migrating. This
Intro
- Bitcoin
+ QtumQTUM
diff --git a/src/qt/locale/bitcoin_zh-Hant.ts b/src/qt/locale/bitcoin_zh-Hant.ts
index 1a7f3a0dd3..383cf1577c 100644
--- a/src/qt/locale/bitcoin_zh-Hant.ts
+++ b/src/qt/locale/bitcoin_zh-Hant.ts
@@ -1371,12 +1371,12 @@ The migration process will create a backup of the wallet before migrating. This
窗体
- Recent transactions may not yet be visible, and therefore your wallet's balance might be incorrect. This information will be correct once your wallet has finished synchronizing with the bitcoin network, as detailed below.
- 最近的交易可能還看不到,因此錢包餘額可能不正確。在錢包軟體完成跟 bitcoin 網路的同步後,這裡的資訊就會正確。詳情請見下面。
+ Recent transactions may not yet be visible, and therefore your wallet's balance might be incorrect. This information will be correct once your wallet has finished synchronizing with the qtum network, as detailed below.
+ 最近的交易可能還看不到,因此錢包餘額可能不正確。在錢包軟體完成跟 qtum 網路的同步後,這裡的資訊就會正確。詳情請見下面。
- Attempting to spend bitcoins that are affected by not-yet-displayed transactions will not be accepted by the network.
- 嘗試花費受尚未顯示的交易影響的比特幣將不會被網路接受。
+ Attempting to spend qtums that are affected by not-yet-displayed transactions will not be accepted by the network.
+ 嘗試花費受尚未顯示的交易影響的QTUM將不會被網路接受。Unknown…
diff --git a/src/qt/locale/bitcoin_zh.ts b/src/qt/locale/bitcoin_zh.ts
index 2c6eb8a99b..d2ecab6fa1 100644
--- a/src/qt/locale/bitcoin_zh.ts
+++ b/src/qt/locale/bitcoin_zh.ts
@@ -917,12 +917,12 @@ The migration process will create a backup of the wallet before migrating. This
ModalOverlay
- Recent transactions may not yet be visible, and therefore your wallet's balance might be incorrect. This information will be correct once your wallet has finished synchronizing with the bitcoin network, as detailed below.
- 最近的交易可能還看不到,因此錢包餘額可能不正確。在錢包軟體完成跟 bitcoin 網路的同步後,這裡的資訊就會正確。詳情請見下面。
+ Recent transactions may not yet be visible, and therefore your wallet's balance might be incorrect. This information will be correct once your wallet has finished synchronizing with the qtum network, as detailed below.
+ 最近的交易可能還看不到,因此錢包餘額可能不正確。在錢包軟體完成跟 qtum 網路的同步後,這裡的資訊就會正確。詳情請見下面。
- Attempting to spend bitcoins that are affected by not-yet-displayed transactions will not be accepted by the network.
- 嘗試花費受尚未顯示的交易影響的比特幣將不會被網路接受。
+ Attempting to spend qtums that are affected by not-yet-displayed transactions will not be accepted by the network.
+ 嘗試花費受尚未顯示的交易影響的QTUM將不會被網路接受。Unknown. Pre-syncing Headers (%1, %2%)…
diff --git a/src/qt/locale/bitcoin_zh_HK.ts b/src/qt/locale/bitcoin_zh_HK.ts
index 6779764ce5..e29d844d6e 100644
--- a/src/qt/locale/bitcoin_zh_HK.ts
+++ b/src/qt/locale/bitcoin_zh_HK.ts
@@ -1403,12 +1403,12 @@ The migration process will create a backup of the wallet before migrating. This
窗体
- Recent transactions may not yet be visible, and therefore your wallet's balance might be incorrect. This information will be correct once your wallet has finished synchronizing with the bitcoin network, as detailed below.
- 最近的交易可能還看不到,因此錢包餘額可能不正確。在錢包軟體完成跟 bitcoin 網路的同步後,這裡的資訊就會正確。詳情請見下面。
+ Recent transactions may not yet be visible, and therefore your wallet's balance might be incorrect. This information will be correct once your wallet has finished synchronizing with the qtum network, as detailed below.
+ 最近的交易可能還看不到,因此錢包餘額可能不正確。在錢包軟體完成跟 qtum 網路的同步後,這裡的資訊就會正確。詳情請見下面。
- Attempting to spend bitcoins that are affected by not-yet-displayed transactions will not be accepted by the network.
- 嘗試花費受尚未顯示的交易影響的比特幣將不會被網路接受。
+ Attempting to spend qtums that are affected by not-yet-displayed transactions will not be accepted by the network.
+ 嘗試花費受尚未顯示的交易影響的QTUM將不會被網路接受。Unknown…
diff --git a/src/qt/locale/bitcoin_zh_TW.ts b/src/qt/locale/bitcoin_zh_TW.ts
index 61b99c2cc3..453791e402 100644
--- a/src/qt/locale/bitcoin_zh_TW.ts
+++ b/src/qt/locale/bitcoin_zh_TW.ts
@@ -2910,8 +2910,8 @@ For more information on using this console, type %6.
隱藏交易手續費設定
- When there is less transaction volume than space in the blocks, miners as well as relaying nodes may enforce a minimum fee. Paying only this minimum fee is just fine, but be aware that this can result in a never confirming transaction once there is more demand for bitcoin transactions than the network can process.
- 當交易量小於可用區塊空間時,礦工和節點可能會執行最低手續費率限制。 以這個最低費率來支付手續費也是可以的,但請注意,一旦交易需求超出比特幣網路能處理的限度,你的交易可能永遠無法確認。
+ When there is less transaction volume than space in the blocks, miners as well as relaying nodes may enforce a minimum fee. Paying only this minimum fee is just fine, but be aware that this can result in a never confirming transaction once there is more demand for qtum transactions than the network can process.
+ 當交易量小於可用區塊空間時,礦工和節點可能會執行最低手續費率限制。 以這個最低費率來支付手續費也是可以的,但請注意,一旦交易需求超出QTUM網路能處理的限度,你的交易可能永遠無法確認。A too low fee might result in a never confirming transaction (read the tooltip)
@@ -3055,7 +3055,7 @@ For more information on using this console, type %6.
Please, review your transaction. You can create and send this transaction or create a Partially Signed Qtum Transaction (PSBT), which you can save or copy and then sign with, e.g., an offline %1 wallet, or a PSBT-compatible hardware wallet.Text to inform a user attempting to create a transaction of their current options. At this stage, a user can send their transaction or create a PSBT. This string is displayed when both private keys and PSBT controls are enabled.
- 請務必仔細檢查您的交易。 你可以創建並發送這筆交易;也可以創建一個“部分簽名比特幣交易(PSBT)”,它可以被保存下來或被複製出去,然後就可以對它進行簽名,比如用離線%1錢包,或 是用相容PSBT的硬體錢包。
+ 請務必仔細檢查您的交易。 你可以創建並發送這筆交易;也可以創建一個“部分簽名QTUM交易(PSBT)”,它可以被保存下來或被複製出去,然後就可以對它進行簽名,比如用離線%1錢包,或 是用相容PSBT的硬體錢包。Please, review your transaction.
@@ -4004,8 +4004,8 @@ Go to File > Open Wallet to load a wallet.
錯誤: 轉儲文件格式不正確。 得到是"%s",而預期本應得到的是 "format"。
- Error: Dumpfile version is not supported. This version of bitcoin-wallet only supports version 1 dumpfiles. Got dumpfile with version %s
- 錯誤: 轉儲文件版本不支援。 這個版本的 bitcoin-wallet 只支援版本為 1 的轉儲檔案。 得到的轉儲文件版本是%s
+ Error: Dumpfile version is not supported. This version of qtum-wallet only supports version 1 dumpfiles. Got dumpfile with version %s
+ 錯誤: 轉儲文件版本不支援。 這個版本的 qtum-wallet 只支援版本為 1 的轉儲檔案。 得到的轉儲文件版本是%sError: Legacy wallets only support the "legacy", "p2sh-segwit", and "bech32" address types
@@ -4782,4 +4782,4 @@ Unable to restore backup of wallet.
設定檔案無法寫入
-
\ No newline at end of file
+
diff --git a/src/qt/locale/bitcoin_es_CO.ts b/src/qt/locale/bitcoin_es_CO.ts
index 0808a05712..214d02bfe0 100644
--- a/src/qt/locale/bitcoin_es_CO.ts
+++ b/src/qt/locale/bitcoin_es_CO.ts
@@ -458,8 +458,8 @@ Solo es posible firmar con direcciones de tipo legacy.
Proxy <b>habilitado</b>: %1
-
- Enviar monedas a una dirección de Bitcoin
+
+ Enviar monedas a una dirección de Qtum
@@ -499,15 +499,15 @@ Solo es posible firmar con direcciones de tipo legacy.
- Firmar mensajes con tus direcciones de Bitcoin para demostrar que te pertenecen
+ Firmar mensajes con tus direcciones de Qtum para demostrar que te pertenecen&Verificar mensaje...
-
- Verificar mensajes para asegurarte de que estén firmados con direcciones de Bitcoin concretas
+
+ Verificar mensajes para asegurarte de que estén firmados con direcciones de Qtum concretas
@@ -566,8 +566,8 @@ Solo es posible firmar con direcciones de tipo legacy.
Conectando a pares...
-
- Solicitar pagos (genera códigos QR y URI de tipo "bitcoin:")
+
+ Solicitar pagos (genera códigos QR y URI de tipo "qtum:")
@@ -1269,8 +1269,8 @@ El proceso de migración creará una copia de seguridad de la billetera antes de
Editar dirección de envío
-
- La dirección ingresada "%1" no es una dirección de Bitcoin válida.
+
+ La dirección ingresada "%1" no es una dirección de Qtum válida.
@@ -1356,8 +1356,8 @@ El proceso de migración creará una copia de seguridad de la billetera antes de
-
- %1 descargará y almacenará una copia de la cadena de bloques de Bitcoin.
+
+ %1 descargará y almacenará una copia de la cadena de bloques de Qtum.
@@ -1441,12 +1441,12 @@ El proceso de migración creará una copia de seguridad de la billetera antes de
Formulario
-
- Es posible que las transacciones recientes aún no sean visibles y, por lo tanto, el saldo de la billetera podría ser incorrecto. Esta información será correcta una vez que la billetera haya terminado de sincronizarse con la red de Bitcoin, como se detalla abajo.
+
+ Es posible que las transacciones recientes aún no sean visibles y, por lo tanto, el saldo de la billetera podría ser incorrecto. Esta información será correcta una vez que la billetera haya terminado de sincronizarse con la red de Qtum, como se detalla abajo.
-
- La red no aceptará si se intenta gastar bitcoins afectados por las transacciones que aún no se muestran.
+
+ La red no aceptará si se intenta gastar qtums afectados por las transacciones que aún no se muestran.
@@ -4896,4 +4896,4 @@ No se puede restaurar la copia de seguridad de la billetera.
El archivo de configuración no se puede escribir
-
\ No newline at end of file
+
diff --git a/src/qt/locale/bitcoin_mi.ts b/src/qt/locale/bitcoin_mi.ts
index 6a67a3e646..c6f4d74fad 100644
--- a/src/qt/locale/bitcoin_mi.ts
+++ b/src/qt/locale/bitcoin_mi.ts
@@ -55,13 +55,13 @@ Right-click to edit address or label
Whiriwhiria te wāhitau hei whiwhi moni
-
- Ko ēnei ngā whakamāoritanga mō ō whakamahi Bitcoin hei tuku moni. Tirohia i te moni me te wāhi whiwhi i mua i te tuku i ngā moni.
+
+ Ko ēnei ngā whakamāoritanga mō ō whakamahi Qtum hei tuku moni. Tirohia i te moni me te wāhi whiwhi i mua i te tuku i ngā moni.
-
@@ -145,8 +145,8 @@ Ko te whakakī i ēnei whakaaronga e taea ana anake ki ngā whakararuraru o te m
Whakamana te whakakītanga pūtea
- Warning: If you encrypt your wallet and lose your passphrase, you will <b>LOSE ALL OF YOUR BITCOINS</b>!
- Whakatūpato: Ki te whakakino i tō pēke moni me te ngaro i tō kupuhipa, ka <b>NGARO KATOA ŌU PĪNIHA BITCOIN</b>!
+ Warning: If you encrypt your wallet and lose your passphrase, you will <b>LOSE ALL OF YOUR QTUMS</b>!
+ Whakatūpato: Ki te whakakino i tō pēke moni me te ngaro i tō kupuhipa, ka <b>NGARO KATOA ŌU PĪNIHA QTUM</b>!Are you sure you wish to encrypt your wallet?
@@ -165,7 +165,7 @@ Ko te whakakī i ēnei whakaaronga e taea ana anake ki ngā whakararuraru o te m
Whakauru te kupu whakapākehā me te kupu hōu mō te pēke moni.
- Remember that encrypting your wallet cannot fully protect your bitcoins from being stolen by malware infecting your computer.
+ Remember that encrypting your wallet cannot fully protect your qtums from being stolen by malware infecting your computer.Mahara kia whakakorehia te whakakino i ō wharepukapuka kia whakararuraru i ō wharepūkoro.
@@ -321,7 +321,7 @@ Ko te whakakī i ēnei whakaaronga e taea ana anake ki ngā whakararuraru o te m
%n active connection(s) to Bitcoin network.
@@ -729,4 +729,4 @@ Ko te whakakī i ēnei whakaaronga e taea ana anake ki ngā whakararuraru o te m
Kāore i taea te tuhi i te kōnae tautuhinga
-
\ No newline at end of file
+
@@ -321,7 +321,7 @@ Ko te whakakī i ēnei whakaaronga e taea ana anake ki ngā whakararuraru o te m
- %n active connection(s) to Bitcoin network.
+ %n active connection(s) to Qtum network.A substring of the tooltip.
Kāore i taea te tuhi i te kōnae tautuhinga
diff --git a/src/qt/locale/bitcoin_sd.ts b/src/qt/locale/bitcoin_sd.ts
index 6497eac9fe..491d386c44 100644
--- a/src/qt/locale/bitcoin_sd.ts
+++ b/src/qt/locale/bitcoin_sd.ts
@@ -88,7 +88,7 @@
%n active connection(s) to Bitcoin network.
@@ -124,7 +124,7 @@
Intro
- Bitcoin
+ Qtumبٽڪوائن
@@ -278,4 +278,4 @@
پتو
-
\ No newline at end of file
+
@@ -88,7 +88,7 @@
- %n active connection(s) to Bitcoin network.
+ %n active connection(s) to Qtum network.A substring of the tooltip.
Intro